@@ -19,7 +19,7 @@ class runlog {
     public $timestamp        = "d-M-Y H:i:s O";
     public $max_line_size    = 150;
 
-    function runlog()
+    function __construct()
     {
         $this->start_time = microtime(true);
     }
@@ -38,8 +38,8 @@ class runlog {
 
         $this->parent_stack[] = $name;
 
-        $this->print_to_console("start: ".$name, $tag, 'start');
-        $this->print_to_file("start: ".$name, $tag, 'start');
+        $this->print_to_console("start: ".$name, $tag);
+        $this->print_to_file("start: ".$name, $tag);
         $this->indent++;
     }
 
@@ -71,12 +71,9 @@ class runlog {
             foreach ($this->tag_count as $tag => $count){
                 $tag_report .= "$tag: $count, ";
             }
-            if (!empty($tag_report)) {
-//                $tag_report = "\n$tag_report\n";
-            }
             $end_txt = sprintf("end: $name - %0.4f seconds $tag_report", $this->run_log[$lastk]['duration']);
-            $this->print_to_console($end_txt, $this->run_log[$lastk]['tag'], 'end');
-            $this->print_to_file($end_txt,  $this->run_log[$lastk]['tag'], 'end');
+            $this->print_to_console($end_txt, $this->run_log[$lastk]['tag']);
+            $this->print_to_file($end_txt,  $this->run_log[$lastk]['tag']);
         }
     }
 
@@ -140,7 +137,7 @@ class runlog {
         $this->print_to_console($msg, $tag);
     }
 
-    public function print_to_file($msg, $tag = false, $type = false)
+    public function print_to_file($msg, $tag = false)
     {
         if (!$tag) {
             $file_handle_tag = 'master';
@@ -223,7 +220,6 @@ class runlog {
         return $buf;
     }
 
-
     function  __destruct()
     {
         foreach ($this->file_handles as $handle) {
